Discovery Connectors
####################

The purpose of this project is to provide a set of connectors that support the Discovery Transitioning Utils initiative

The connectors provides a set of concrete implemetation of the abstract classes ``AbstractSourceHandler``,
``AbstractPersistHandler`` and ``AbstractConnectorContract``

